﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using DlhSoft.ProjectData.GanttChart.WinRT.Controls;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace ScheduleChartViewSample
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private static readonly DateTime date = DateTime.Today;
        private static readonly int year = date.Year, month = date.Month;

        public MainPage()
        {
            this.InitializeComponent();
            this.NavigationCacheMode = NavigationCacheMode.Required;
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.
        /// This parameter is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            this.InitializeScheduleChartView();
        }

        private void InitializeScheduleChartView()
        {
            // Prepare data items.
            var items = new ObservableCollection<ScheduleChartItem>
            {
                new ScheduleChartItem { Content = "Resource 1", GanttChartItems = new ObservableCollection<GanttChartItem> { new GanttChartItem { Content = "Task A (Resource 1)", Start = new DateTime(year, month, 2, 8, 0, 0), Finish = new DateTime(year, month, 8, 16, 0, 0), CompletedFinish = new DateTime(year, month, 5, 16, 0, 0) } } },
                new ScheduleChartItem { Content = "Resource 2", GanttChartItems = new ObservableCollection<GanttChartItem> { new GanttChartItem { Content = "Task A (Resource 2)", Start = new DateTime(year, month, 2, 8, 0, 0), Finish = new DateTime(year, month, 8, 16, 0, 0), CompletedFinish = new DateTime(year, month, 5, 16, 0, 0), AssignmentsContent = "50%" },
                                                                                                                             new GanttChartItem { Content = "Task B (Resource 2)", Start = new DateTime(year, month, 11, 8, 0, 0), Finish = new DateTime(year, month, 12, 16, 0, 0), CompletedFinish = new DateTime(year, month, 12, 16, 0, 0) }, 
                                                                                                                             new GanttChartItem { Content = "Task C (Resource 2)", Start = new DateTime(year, month, 14, 8, 0, 0), Finish = new DateTime(year, month, 14, 16, 0, 0) } } },
                new ScheduleChartItem { Content = "Resource 3", GanttChartItems = new ObservableCollection<GanttChartItem> { new GanttChartItem { Content = "Task D (Resource 3)", Start = new DateTime(year, month, 12, 12, 0, 0), Finish = new DateTime(year, month, 14, 16, 0, 0) } } }
            };
            for (int i = 4; i <= 32; i++)
            {
                items.Add(new ScheduleChartItem
                {
                    Content = "Resource " + i,
                    GanttChartItems = new ObservableCollection<GanttChartItem> { new GanttChartItem { Content = "Task X (Resource " + i + ")", Start = new DateTime(year, month, 2, 8, 0, 0), Finish = new DateTime(year, month, 5, 16, 0, 0) },
                                                                                 new GanttChartItem { Content = "Task Y (Resource " + i + ")", Start = new DateTime(year, month, 7, 8, 0, 0), Finish = new DateTime(year, month, 8, 16, 0, 0) } }
                });
            }
            ScheduleChartView.Items = items;

            // Optionally, hide data grid or set grid and chart widths, and/or set read only settings.
            // ScheduleChartView.IsGridVisible = false;
            // ScheduleChartView.GridWidthPercent = 10;
            // ScheduleChartView.ChartWidthPercent = 90;
            // ScheduleChartView.IsGridReadOnly = true;
            // ScheduleChartView.IsChartReadOnly = true;

            // Set the scrollable timeline to present, and the displayed and current time values to automatically scroll to a specific chart coordinate, and display a vertical bar highlighter at the specified point.
            ScheduleChartView.TimelineStart = new DateTime(year, month, 1).AddDays(-7);
            ScheduleChartView.TimelineFinish = new DateTime(year + 1, month, 1);
            ScheduleChartView.DisplayedTime = new DateTime(year, month, 1);
            ScheduleChartView.CurrentTime = new DateTime(year, month, 2, 12, 0, 0);

            // Optionally, configure the chart scales and their display settings.
            // ScheduleChartView.HeaderHeight = 21 * 3;
            // ScheduleChartView.Scales = new List<Scale>
            // {
            //     new Scale { ScaleType = ScaleType.Months, HeaderTextFormat = ScaleHeaderTextFormat.Month, IsSeparatorVisible = true },
            //     new Scale { ScaleType = ScaleType.Weeks, HeaderTextFormat = ScaleHeaderTextFormat.Date, IsSeparatorVisible = true },
            //     new Scale { ScaleType = ScaleType.Days, HeaderTextFormat = ScaleHeaderTextFormat.Day }
            // };
            // ScheduleChartView.CurrentTimeLineColor = Colors.Red;
            // ScheduleChartView.UpdateScaleInterval = TimeSpan.FromHours(1);

            // Optionally, zoom in or out to display more time details or higher level project overviews.
            // ScheduleChartView.HourWidth = 5;

            // Optionally, configure the working time schedule of the week and week days.
            // ScheduleChartView.VisibleWeekStart = (int)DayOfWeek.Monday;
            // ScheduleChartView.VisibleWeekFinish = (int)DayOfWeek.Friday;
            // ScheduleChartView.WorkingWeekStart = (int)DayOfWeek.Monday;
            // ScheduleChartView.WorkingWeekFinish = (int)DayOfWeek.Thursday;
            // ScheduleChartView.VisibleDayStart = TimeSpan.Parse("10:00:00"); // 10 AM
            // ScheduleChartView.VisibleDayFinish = TimeSpan.Parse("20:00:00");  // 8 PM
            // ScheduleChartView.SpecialNonworkingDays = new List<DateTimeOffset>() { new DateTime(year, month, 24), new DateTime(year, month, 25) };

            // Optionally, set custom appearance settings.
            // ScheduleChartView.BorderColor = Colors.Gray;
            // ScheduleChartView.StandardBarStroke = Colors.Green;
            // ScheduleChartView.StandardBarFill = Colors.LightGreen;
            // ScheduleChartView.StandardCompletedBarFill = Colors.DarkGreen;
            // ScheduleChartView.StandardCompletedBarStroke = Colors.DarkGreen;

            // Optionally, display alternative row background.
            // ScheduleChartView.AlternativeRowBackgroundColor = Color.FromArgb(0xff, 0xf5, 0xf5, 0xf5);

            // Optionally, configure selection appearance.
            // ScheduleChartView.SelectedItemBackgroundColor = Colors.LightCyan;

            // Optionally, initialize item selection.
            // ScheduleChartView.SelectedItem = ScheduleChartView.Items[1];

            // Optionally, configure columns.
            // ScheduleChartView.Columns[(int)ColumnType.Content].Header = "Workers";
            // ScheduleChartView.Columns[(int)ColumnType.Content].Width = 240;
            // ScheduleChartView.Columns[(int)ColumnType.RowHeader].IsVisible = false;

            // Optionally, set custom item properties, and append read only custom columns bound to their values.
            // ScheduleChartView.Items[1].SetCustomValue("Description", "Custom description");
            // ScheduleChartView.Columns.Add(new Column { Header = "Description", Width = 200, PropertyName = "Description" });

            // Optionally, receive individual notifications for the item property changes that have occured on the client side by handling the ItemPropertyChanged and/or GanttChartItemPropertyChanged events.
            // ScheduleChartView.ItemPropertyChanged += delegate(object sender, ScheduleChartItemPropertyChangedEventArgs change)
            // {
            //     if (change.IsDirect && change.IsFinal && change.PropertyName != "IsSelected")
            //     {
            //         MessageDialog dialog = new MessageDialog(string.Format("{1} property has changed for {0}.", change.Item.Content, change.PropertyName));
            //         dialog.ShowAsync();
            //     }
            // };
            // ScheduleChartView.GanttChartItemPropertyChanged += delegate(object sender, GanttChartItemPropertyChangedEventArgs change)
            // {
            //     if (change.IsDirect && change.IsFinal)
            //     {
            //         MessageDialog dialog = new MessageDialog(string.Format("{1} property has changed for {0}.", change.Item.Content, change.PropertyName));
            //         dialog.ShowAsync();
            //     }
            // };
        }
    }
}
